@@ -253,7 +253,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.18-15/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.18-15/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.18-15/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.19-17/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.19-17/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.19-17/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -334,6 +334,8 @@
 #define HAVE_CHARSET_utf16 1
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
+#define HAVE_X509_CHECK_HOST 1
+#define HAVE_X509_CHECK_IP 1
 
 /*
  * Feature set
@@ -389,15 +391,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 18
-#define MYSQL_VERSION_EXTRA "-15"
+#define MYSQL_VERSION_PATCH 19
+#define MYSQL_VERSION_EXTRA "-17"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.18-15"
+#define PACKAGE_STRING "MySQL Server 5.7.19-17"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.18-15"
-#define VERSION "5.7.18-15"
+#define PACKAGE_VERSION "5.7.19-17"
+#define VERSION "5.7.19-17"
 #define PROTOCOL_VERSION 10
 
 /*
